@@ -87,8 +87,11 @@ class RDFLib(HandlerPlugin):
         del self[g]
 
     def query(self, *av, **kw):
-        g = ConjunctiveGraph(self.store)
-        return g.query(*av, **kw)
+        if hasattr(self.store, "sparql_query"):
+            return self.store.sparql_query(*av, **kw)
+        else:
+            g = ConjunctiveGraph(self.store)
+            return g.query(*av, **kw)
 
 class FourStore(RDFLib):
     """
